@@ -7,8 +7,11 @@
 #include "termptyesc.h"
 #include "termptyops.h"
 #include "termptysave.h"
-#include "termio.h"
 #include "keyin.h"
+#if !defined(ENABLE_FUZZING) && !defined(ENABLE_TESTS)
+# include "win.h"
+#endif
+#include "termio.h"
 #include <sys/types.h>
 #include <signal.h>
 #include <sys/wait.h>
@@ -226,7 +229,8 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
 {
    char buf[4097];
    Eina_Unicode codepoint[4097];
-   int len, i, j, k, reads;
+   int len, i, j, reads;
+   unsigned int k;
 
    if (ecore_main_fd_handler_active_get(fd_handler, ECORE_FD_ERROR))
      {
@@ -302,7 +306,7 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
         j = 0;
         for (i = 0; i < len;)
           {
-             int g = 0, prev_i = i;
+             Eina_Unicode g = 0, prev_i = i;
 
              if (buf[i])
                {
@@ -311,8 +315,8 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
                       (len - prev_i) <= (int)sizeof(ty->oldbuf))
                     {
                        for (k = 0;
-                            (k < (int)sizeof(ty->oldbuf)) && 
-                            (k < (len - prev_i));
+                            (k < (unsigned int)sizeof(ty->oldbuf)) &&
+                            (k < (unsigned int)(len - prev_i));
                             k++)
                          {
                             ty->oldbuf[k] = buf[prev_i+k];
@@ -334,7 +338,7 @@ _fd_read_do(Termpty *ty, Ecore_Fd_Handler *fd_handler, Eina_Bool false_on_empty)
         termpty_handle_buf(ty, codepoint, j);
      }
    if (ty->cb.change.func) ty->cb.change.func(ty->cb.change.data);
-#ifdef ENABLE_FUZZING
+#if defined(ENABLE_FUZZING) || defined(ENABLE_TESTS)
    if (len <= 0)
      {
         ty->exit_code = 0;
@@ -475,9 +479,8 @@ _is_shell_valid(const char *cmd)
 
 Termpty *
 termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
-            int w, int h, int backscroll, Eina_Bool xterm_256color,
-            Eina_Bool erase_is_del, const char *emotion_mod,
-            const char *title)
+            int w, int h, Config *config, const char *emotion_mod,
+            const char *title, Ecore_Window window_id)
 {
    Termpty *ty;
    const char *pty;
@@ -490,9 +493,10 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
 
    ty = calloc(1, sizeof(Termpty));
    if (!ty) return NULL;
+   ty->config = config;
    ty->w = w;
    ty->h = h;
-   ty->backsize = backscroll;
+   ty->backsize = config->scrollback;
 
    ty->screen = calloc(1, sizeof(Termcell) * ty->w * ty->h);
    if (!ty->screen)
@@ -525,7 +529,7 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
 
    ty->circular_offset = 0;
 
-#ifdef ENABLE_FUZZING
+#if defined(ENABLE_FUZZING) || defined(ENABLE_TESTS)
    ty->fd = STDIN_FILENO;
    ty->hand_fd = ecore_main_fd_handler_add(ty->fd,
                                            ECORE_FD_READ | ECORE_FD_ERROR,
@@ -625,7 +629,7 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
         ERR("unable to tcgetattr: %s", strerror(errno));
         goto err;
      }
-   t.c_cc[VERASE] =  (erase_is_del) ? 0x7f : 0x8;
+   t.c_cc[VERASE] =  (config->erase_is_del) ? 0x7f : 0x8;
 #ifdef IUTF8
    t.c_iflag |= IUTF8;
 #endif
@@ -705,7 +709,7 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
         unsetenv("LINES");
 
         /* pretend to be xterm */
-        if (xterm_256color)
+        if (config->xterm_256color)
           {
              putenv("TERM=xterm-256color");
           }
@@ -719,6 +723,11 @@ termpty_new(const char *cmd, Eina_Bool login_shell, const char *cd,
              snprintf(buf, sizeof(buf), "EMOTION_ENGINE=%s", emotion_mod);
              putenv(buf);
           }
+        if (window_id)
+          {
+             snprintf(buf, sizeof(buf), "WINDOWID=%lu", window_id);
+             putenv(buf);
+          }
         if (!login_shell)
           execvp(args[0], (char *const *)args);
         else
@@ -840,16 +849,20 @@ termpty_free(Termpty *ty)
    free(ty);
 }
 
+void
+termpty_config_update(Termpty *ty, Config *config)
+{
+   ty->config = config;
+   termpty_backlog_size_set(ty, config->scrollback);
+}
+
 static Eina_Bool
 _termpty_cell_is_empty(const Termcell *cell)
 {
-   if ((cell->codepoint != 0) &&
-       (!cell->att.invisible) &&
-       (cell->att.fg != COL_INVIS))
-     {
-        return EINA_FALSE;
-     }
-   return EINA_TRUE;
+   return ((cell->codepoint == 0) ||
+           (cell->att.invisible) ||
+           (cell->att.fg == COL_INVIS)) &&
+      ((cell->att.bg == COL_INVIS) || (cell->att.bg == COL_DEF));
 }
 
 static Eina_Bool
@@ -1198,10 +1211,12 @@ termpty_cellrow_get(Termpty *ty, int y_requested, ssize_t *wret)
 {
    if (y_requested >= 0)
      {
+        Termcell *cells = &(TERMPTY_SCREEN(ty, 0, y_requested));
         if (y_requested >= ty->h)
           return NULL;
-        *wret = ty->w;
-        return &(TERMPTY_SCREEN(ty, 0, y_requested));
+
+        *wret = termpty_line_length(cells, ty->w);
+        return cells;
      }
    if (!ty->back)
      return NULL;
@@ -1236,15 +1251,18 @@ termpty_cell_get(Termpty *ty, int y_requested, int x_requested)
 void
 termpty_write(Termpty *ty, const char *input, int len)
 {
+#if defined(ENABLE_TESTS)
+   ty_sb_add(&ty->write_buffer, input, len);
+#else
    int fd = ty->fd;
-
-#ifdef ENABLE_FUZZING
+#if defined(ENABLE_FUZZING)
    fd = ty->fd_dev_null;
 #endif
    if (fd < 0) return;
    if (write(fd, input, len) < 0)
      ERR(_("Could not write to file descriptor %d: %s"),
          fd, strerror(errno));
+#endif
 }
 
 struct screen_info
@@ -1446,6 +1464,7 @@ termpty_resize(Termpty *ty, int new_w, int new_h)
    ty->cursor_state.cy = (new_si.cy >= 0) ? new_si.cy : 0;
    ty->cursor_state.cx = (new_si.cx >= 0) ? new_si.cx : 0;
    ty->circular_offset = new_si.circular_offset;
+   ty->circular_offset2 = 0;
 
    ty->w = new_w;
    ty->h = new_h;
@@ -1722,12 +1741,6 @@ termpty_cell_codepoint_att_fill(Termpty *ty, Eina_Unicode codepoint,
      }
 }
 
-Config *
-termpty_config_get(const Termpty *ty)
-{
-   return termio_config_get(ty->obj);
-}
-
 /* 0 means error here */
 static uint16_t
 _find_empty_slot(const Termpty *ty)
@@ -1830,3 +1843,34 @@ term_link_free(Termpty *ty, Term_Link *link)
    /* Remove from bitmap */
    hl_bitmap_clear_bit(ty, id);
 }
+#if !defined(ENABLE_FUZZING) && !defined(ENABLE_TESTS)
+int
+termpty_color_class_get(Termpty *ty, const char *key,
+                        int *r, int *g, int *b, int *a)
+{
+   Term *term;
+
+   term = termio_term_get(ty->obj);
+   if (term)
+     {
+        Evas_Object *bg = term_bg_get(term);
+        if (!edje_object_color_class_get(bg, key,
+                                         r,
+                                         g,
+                                         b,
+                                         a,
+                                         NULL, NULL, NULL, NULL,
+                                         NULL, NULL, NULL, NULL))
+          {
+             ERR("color class BG not found in theme");
+             return -1;
+          }
+     }
+   else
+     {
+        ERR("term not found");
+        return -1;
+     }
+   return 0;
+}
+#endif
