@@ -13,7 +13,6 @@ void term_unfocus(Term *term);
 void term_focus(Term *term);
 
 Evas_Object *term_termio_get(const Term *term);
-Evas_Object *term_miniview_get(const Term *term);
 void term_miniview_toggle(Term *term);
 void term_set_title(Term *term);
 void term_miniview_hide(Term *term);
@@ -41,7 +40,6 @@ int win_term_set(Win *wn, Term *term);
 Eina_List *
 terms_from_win_object(Evas_Object *win);
 
-Evas_Object *win_base_get(const Win *wn);
 Evas_Object *win_evas_object_get(const Win *win);
 Eina_List * win_terms_get(const Win *wn);
 Config *win_config_get(const Win *wn);
@@ -61,18 +59,18 @@ Term *term_prev_get(const Term *term);
 void term_next(Term *term);
 void term_prev(Term *term);
 Win * term_win_get(const Term *term);
+Evas_Object *term_bg_get(const Term *term);
 
 void term_up(Term *term);
 void term_down(Term *term);
 void term_left(Term *term);
 void term_right(Term *term);
 
-const char *
-term_preedit_str_get(Term *term);
 Ecore_IMF_Context *
 term_imf_context_get(Term *term);
 
 Eina_Bool term_is_visible(Term *term);
+Eina_Bool term_is_focused(Term *term);
 
 void win_font_size_set(Win *wn, int new_size);
 void win_font_update(Term *term);
@@ -91,4 +89,6 @@ void
 term_apply_shine(Term *term, int shine);
 void background_set_shine(Config *config, Evas_Object *bg);
 
+void main_trans_update(const Config *config);
+
 #endif
